package com.sunyo.wlpt.message.bus.sdk.request;

import com.sunyo.wlpt.message.bus.sdk.response.ResultJson;
import com.sunyo.wlpt.message.bus.sdk.utils.GsonUtil;
import com.sunyo.wlpt.message.bus.sdk.utils.OkHttpUtils;
import org.springframework.util.StringUtils;

import java.io.IOException;
import java.util.HashMap;

/**
 * @author 子诚
 * Description：
 * 时间：2020/9/3 15:18
 */
public class MessageService {

    /**
     * 发送消息，根据参数
     *
     * @param url  地址
     * @param SERV 服务器名称
     * @param VSHT 虚拟主机名称
     * @param TYPE 大类型（交换机名称）
     * @param STYP 小类型（路由键名称）
     * @param MSG  发送消息内容
     * @param SNDR 发送者名称
     * @param DDTM yyyyMMddHHmmss格式的发送时间
     * @param TOKN token令牌
     * @param SEQN 序列号
     * @param RCVR 指定接收队列（非必须）
     * @return
     * @throws IOException
     */
    public static ResultJson productNew(String url, String SERV, String VSHT, String TYPE, String STYP,
                                        String MSG, String SNDR, String DDTM, String TOKN, String SEQN, String RCVR)
    {
        HashMap<String, String> params = new HashMap<>();
        params.put("SERV", SERV);
        params.put("VSHT", VSHT);
        params.put("TYPE", TYPE);
        params.put("STYP", STYP);
        params.put("MSG", MSG);
        params.put("SNDR", SNDR);
        params.put("DDTM", DDTM);
        params.put("TOKN", TOKN);
        params.put("SEQN", SEQN);
        params.put("RCVR", RCVR);

        OkHttpUtils okHttp = new OkHttpUtils();
        String json = okHttp.doPostForm(url, TOKN, params);
        if (StringUtils.isEmpty(json)) {
            return new ResultJson<>("10400", "请检查url、token以及以及参数内容与位置");
        }
        ResultJson result = GsonUtil.GsonToBean(json, ResultJson.class);
        return result;
    }

    /**
     * 发送消息，根据参数
     *
     * @param url  地址
     * @param SERV 服务器名称
     * @param VSHT 虚拟主机名称
     * @param TYPE 大类型（交换机名称）
     * @param STYP 小类型（路由键名称）
     * @param MSG  发送消息内容
     * @param SNDR 发送者名称
     * @param DDTM yyyyMMddHHmmss格式的发送时间
     * @param TOKN token令牌
     * @param SEQN 序列号
     * @return
     * @throws IOException
     */
    public static ResultJson productNew(String url, String SERV, String VSHT, String TYPE, String STYP,
                                        String MSG, String SNDR, String DDTM, String TOKN, String SEQN)
    {
        HashMap<String, String> params = new HashMap<>();
        params.put("SERV", SERV);
        params.put("VSHT", VSHT);
        params.put("TYPE", TYPE);
        params.put("STYP", STYP);
        params.put("MSG", MSG);
        params.put("SNDR", SNDR);
        params.put("DDTM", DDTM);
        params.put("TOKN", TOKN);
        params.put("SEQN", SEQN);

        OkHttpUtils okHttp = new OkHttpUtils();
        String json = okHttp.doPostForm(url, TOKN, params);
        if (StringUtils.isEmpty(json)) {
            return new ResultJson<>("10400", "请检查url、token以及以及参数内容与位置");
        }
        ResultJson result = GsonUtil.GsonToBean(json, ResultJson.class);
        return result;
    }

    /**
     * 发送消息,xml报文形式
     *
     * @param xmlMessage xml报文
     * @return
     * @throws IOException
     */
    public ResultJson productOld(String url, String token, String xmlMessage)
    {
        HashMap<String, String> params = new HashMap<>();
        params.put("xmlMessage", xmlMessage);

        OkHttpUtils okHttp = new OkHttpUtils();
        String json = okHttp.doPostForm(url, token, params);
        if (StringUtils.isEmpty(json)) {
            return new ResultJson<>("10400", "请检查url、token以及报文格式");
        }
        ResultJson result = GsonUtil.GsonToBean(json, ResultJson.class);
        return result;
    }

    /**
     * 指定队列，接收一条消息
     *
     * @param RUSR 接收者
     * @param SERV 服务器名称
     * @param VSHT 虚拟主机名称
     * @param RCVR 队列名称
     * @return
     * @throws IOException
     */
    public static ResultJson consumerOne(String url, String token, String RUSR, String SERV, String VSHT, String RCVR)
    {
        HashMap<String, Object> params = new HashMap<>();
        params.put("RUSR", RUSR);
        params.put("SERV", SERV);
        params.put("VSHT", VSHT);
        params.put("RCVR", RCVR);

        OkHttpUtils okHttp = new OkHttpUtils();
        String json = okHttp.doGet(url, token, params);
        if (StringUtils.isEmpty(json)) {
            return new ResultJson<>("20400", "请检查url、token以及以及参数内容与位置");
        }
        ResultJson result = GsonUtil.GsonToBean(json, ResultJson.class);
        return result;
    }

    /**
     * 指定队列，接收多条消息
     *
     * @param RUSR 接收者
     * @param SERV 服务器名称
     * @param VSHT 虚拟主机名称
     * @param RCVR 队列名称
     * @param CUNT 接收消息的数量
     * @return
     * @throws IOException
     */
    public static ResultJson consumerMore(String url, String token, String RUSR, String SERV, String VSHT, String RCVR, Integer CUNT)
    {
        HashMap<String, Object> params = new HashMap<>();
        params.put("RUSR", RUSR);
        params.put("SERV", SERV);
        params.put("VSHT", VSHT);
        params.put("RCVR", RCVR);
        params.put("CUNT", CUNT);

        OkHttpUtils okHttp = new OkHttpUtils();
        String json = okHttp.doGet(url, token, params);
        if (StringUtils.isEmpty(json)) {
            return new ResultJson<>("20400", "请检查url、token以及以及参数内容与位置");
        }
        ResultJson result = GsonUtil.GsonToBean(json, ResultJson.class);
        return result;
    }
}
