package com.sunyo.wlpt.message.bus.sdk.utils;

import lombok.extern.slf4j.Slf4j;
import okhttp3.*;
import org.apache.commons.lang3.StringUtils;


import java.net.URLEncoder;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author 子诚
 * Description：
 * 时间：2020/9/3 15:22
 */
@Slf4j
public class OkHttpUtils {


    private static final MediaType MEDIA_TYPE_JSON = MediaType.parse("application/json; charset=utf-8");
    private static final MediaType MEDIA_TYPE_TEXT = MediaType.parse("application/x-www-form-urlencoded; charset=utf-8");
    private static final byte[] LOCKER = new byte[0];
    private static OkHttpUtils instance;
    private OkHttpClient okHttpClient;

    public OkHttpUtils()
    {
        okHttpClient = new OkHttpClient.Builder()
                //10秒连接超时
                .connectTimeout(60, TimeUnit.SECONDS)
                //10m秒写入超时
                .writeTimeout(600, TimeUnit.SECONDS)
                //10秒读取超时
                .readTimeout(600, TimeUnit.SECONDS)
                .build();
    }

    public static OkHttpUtils getInstance()
    {
        if (instance == null) {
            synchronized (LOCKER) {
                if (instance == null) {
                    instance = new OkHttpUtils();
                }
            }
        }
        return instance;
    }

    public String doGet(String url)
    {
        if (isBlankUrl(url)) {
            return null;
        }
        Request request = getRequestForGet(url);
        return commonRequest(request);
    }

    public String doGet(String url, String token, HashMap<String, Object> params)
    {
        if (isBlankUrl(url)) {
            return null;
        }
        Request request = getRequestForGet(url, token, params);
        return commonRequest(request);
    }

    public String doPostJson(String url, String json)
    {
        if (isBlankUrl(url)) {
            return null;
        }
        Request request = getRequestForPostJson(url, json);
        return commonRequest(request);
    }

    public String doPostForm(String url, String token, Map<String, String> params)
    {
        if (isBlankUrl(url)) {
            return null;
        }
        Request request = getRequestForPostForm(url, token, params);
        return commonRequest(request);
    }

    private Boolean isBlankUrl(String url)
    {
        if (StringUtils.isBlank(url)) {
            log.info("url is blank-->" + url);
            return true;
        } else {
            return false;
        }
    }

    private String commonRequest(Request request)
    {
        String re = "";
        try {
            Call call = okHttpClient.newCall(request);
            Response response = call.execute();
            if (response.isSuccessful()) {
                re = response.body().string();
            } else {
                log.error("request failure url:{};message:{}", request.url().toString(), response.message());
            }
        } catch (Exception e) {
            log.error("request execute failure", e);
        }
        return re;
    }

    private Request getRequestForPostJson(String url, String json)
    {
        RequestBody body = RequestBody.create(MEDIA_TYPE_JSON, json);
        Request request = new Request.Builder()
                .url(url)
                .post(body)
                .build();
        return request;
    }


    private Request getRequestForPostForm(String url, String token, Map<String, String> params)
    {
        if (params == null) {
            params = new HashMap<>();
        }
        FormBody.Builder builder = new FormBody.Builder();
        if (params != null && params.size() > 0) {
            for (Map.Entry<String, String> entry : params.entrySet()) {
                builder.addEncoded(entry.getKey(), entry.getValue());
            }
        }
        RequestBody requestBody = builder.build();
        Request request = new Request.Builder()
                .url(url)
                .addHeader("Authorization", token)
                .post(requestBody)
                .build();
        return request;
    }

    private Request getRequestForGet(String url, String token, HashMap<String, Object> params)
    {
        Request request = new Request.Builder()
                .url(getUrlStringForGet(url, params))
                .addHeader("Authorization", token)
                .build();
        return request;
    }

    private Request getRequestForGet(String url)
    {
        Request request = new Request.Builder()
                .url(url)
                .build();
        return request;
    }

    private String getUrlStringForGet(String url, HashMap<String, Object> params)
    {
        StringBuilder urlBuilder = new StringBuilder();
        urlBuilder.append(url);
        urlBuilder.append("?");
        if (params != null && params.size() > 0) {
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                try {
                    urlBuilder.append("&").append(entry.getKey()).append("=").append(
                            "CUNT".equals(entry.getKey())
                                    ? entry.getValue()
                                    : URLEncoder.encode((String) entry.getValue(), "UTF-8")
                    );
                } catch (Exception e) {
                    urlBuilder.append("&").append(entry.getKey()).append("=").append(entry.getValue());
                }
            }
        }
        return urlBuilder.toString();
    }

}